class DirSearch

  attr_reader   :dir, :term
  attr_accessor :count

  def initialize(dir, term)
    @count = 0
    @dir   = dir
    @term  = term
  end

  def process_file(name)
    File.open(name) do |f|
      lines = f.readlines
      lines = lines.find_all { |line| line.include?(@term) }
      if lines.size > 0
        @count += 1
      end
    end
  end

  def process_directory(dir)
    dirs = dir.entries
    dirs.delete_if { |entry| entry =~ /^\./ }
    dirs.delete_if { |entry| entry =~ /\.rb$/ }
    dirs.each { |entry| 
      full_path = File.join(dir.path, entry)
      if File.directory?(full_path)
        process_directory(Dir.new(full_path))
      else
        process_file(full_path)
      end
    }
  end

  def search
    process_directory(Dir.new(@dir))
  end

end

threads = []

current_dir = `pwd`.chomp
dir = Dir.new(current_dir)
dirs = dir.entries
dirs.delete_if { |entry| entry =~ /^\./ }
dirs.delete_if { |entry| entry =~ /\.rb$/ }
dirs.each { |entry| 
  full_path = File.join(dir.path, entry)
  if File.directory?(full_path)
    threads << Thread.new {
      Thread.current[:search] = DirSearch.new(full_path, "iran")
      Thread.current[:search].search
    }
  end
}

count = 0
threads.each { |t|
  t.join
  count += t[:search].count
}

puts "#{count}"
